# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseServiceInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'auth_key': 'str',
        'created_by': 'ResponseSimpleUser',
        'created_dt': 'datetime',
        'id': 'int',
        'model': 'ResponseSimpleModelInfo',
        'serving_endpoint': 'OrmWorkloadEndpoint',
        'ssh_endpoint': 'OrmWorkloadEndpoint',
        'updated_dt': 'datetime'
    }

    attribute_map = {
        'auth_key': 'auth_key',
        'created_by': 'created_by',
        'created_dt': 'created_dt',
        'id': 'id',
        'model': 'model',
        'serving_endpoint': 'serving_endpoint',
        'ssh_endpoint': 'ssh_endpoint',
        'updated_dt': 'updated_dt'
    }

    def __init__(self, auth_key=None, created_by=None, created_dt=None, id=None, model=None, serving_endpoint=None, ssh_endpoint=None, updated_dt=None, local_vars_configuration=None):  # noqa: E501
        """ResponseServiceInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._auth_key = None
        self._created_by = None
        self._created_dt = None
        self._id = None
        self._model = None
        self._serving_endpoint = None
        self._ssh_endpoint = None
        self._updated_dt = None
        self.discriminator = None

        self.auth_key = auth_key
        self.created_by = created_by
        self.created_dt = created_dt
        self.id = id
        self.model = model
        if serving_endpoint is not None:
            self.serving_endpoint = serving_endpoint
        if ssh_endpoint is not None:
            self.ssh_endpoint = ssh_endpoint
        self.updated_dt = updated_dt

    @property
    def auth_key(self):
        """Gets the auth_key of this ResponseServiceInfo.  # noqa: E501


        :return: The auth_key of this ResponseServiceInfo.  # noqa: E501
        :rtype: str
        """
        return self._auth_key

    @auth_key.setter
    def auth_key(self, auth_key):
        """Sets the auth_key of this ResponseServiceInfo.


        :param auth_key: The auth_key of this ResponseServiceInfo.  # noqa: E501
        :type auth_key: str
        """
        if self.local_vars_configuration.client_side_validation and auth_key is None:  # noqa: E501
            raise ValueError("Invalid value for `auth_key`, must not be `None`")  # noqa: E501

        self._auth_key = auth_key

    @property
    def created_by(self):
        """Gets the created_by of this ResponseServiceInfo.  # noqa: E501


        :return: The created_by of this ResponseServiceInfo.  # noqa: E501
        :rtype: ResponseSimpleUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ResponseServiceInfo.


        :param created_by: The created_by of this ResponseServiceInfo.  # noqa: E501
        :type created_by: ResponseSimpleUser
        """
        if self.local_vars_configuration.client_side_validation and created_by is None:  # noqa: E501
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def created_dt(self):
        """Gets the created_dt of this ResponseServiceInfo.  # noqa: E501


        :return: The created_dt of this ResponseServiceInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this ResponseServiceInfo.


        :param created_dt: The created_dt of this ResponseServiceInfo.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def id(self):
        """Gets the id of this ResponseServiceInfo.  # noqa: E501


        :return: The id of this ResponseServiceInfo.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ResponseServiceInfo.


        :param id: The id of this ResponseServiceInfo.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def model(self):
        """Gets the model of this ResponseServiceInfo.  # noqa: E501


        :return: The model of this ResponseServiceInfo.  # noqa: E501
        :rtype: ResponseSimpleModelInfo
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this ResponseServiceInfo.


        :param model: The model of this ResponseServiceInfo.  # noqa: E501
        :type model: ResponseSimpleModelInfo
        """
        if self.local_vars_configuration.client_side_validation and model is None:  # noqa: E501
            raise ValueError("Invalid value for `model`, must not be `None`")  # noqa: E501

        self._model = model

    @property
    def serving_endpoint(self):
        """Gets the serving_endpoint of this ResponseServiceInfo.  # noqa: E501


        :return: The serving_endpoint of this ResponseServiceInfo.  # noqa: E501
        :rtype: OrmWorkloadEndpoint
        """
        return self._serving_endpoint

    @serving_endpoint.setter
    def serving_endpoint(self, serving_endpoint):
        """Sets the serving_endpoint of this ResponseServiceInfo.


        :param serving_endpoint: The serving_endpoint of this ResponseServiceInfo.  # noqa: E501
        :type serving_endpoint: OrmWorkloadEndpoint
        """

        self._serving_endpoint = serving_endpoint

    @property
    def ssh_endpoint(self):
        """Gets the ssh_endpoint of this ResponseServiceInfo.  # noqa: E501


        :return: The ssh_endpoint of this ResponseServiceInfo.  # noqa: E501
        :rtype: OrmWorkloadEndpoint
        """
        return self._ssh_endpoint

    @ssh_endpoint.setter
    def ssh_endpoint(self, ssh_endpoint):
        """Sets the ssh_endpoint of this ResponseServiceInfo.


        :param ssh_endpoint: The ssh_endpoint of this ResponseServiceInfo.  # noqa: E501
        :type ssh_endpoint: OrmWorkloadEndpoint
        """

        self._ssh_endpoint = ssh_endpoint

    @property
    def updated_dt(self):
        """Gets the updated_dt of this ResponseServiceInfo.  # noqa: E501


        :return: The updated_dt of this ResponseServiceInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this ResponseServiceInfo.


        :param updated_dt: The updated_dt of this ResponseServiceInfo.  # noqa: E501
        :type updated_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseServiceInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseServiceInfo):
            return True

        return self.to_dict() != other.to_dict()
